@@ -1,13 +1,16 @@
 import os
 
 
-def output(value):
+def output(value, newline=False):
     """
     输出变量
 
     :param value: 变量
+    :param newline: 是否换行
     :return:
     """
+    if newline:
+        print(f'表达式：{repr(value)} \n 类型：{type(value)} \n 值：{value}')
     print(f'表达式：{repr(value)} ----- 类型：{type(value)} ----- 值：{value}')
 
 
